OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Visualizador",
    "Simple file viewer with slideshow for media" : "Um visualizador de ficheiros com diaporamas para multimédia",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Mostra as suas fotografias e os vídeos das suas últimas férias como nos cinemas, mostra um excerto do seu romance mais recente diretamente do seu nextcloud, escolhe o melhor GIF da sua coleção devido à pré-visualização direta dos seus ficheiros favoritos e muito mais!",
    "Your browser does not support audio." : "O seu navegador não suporta áudio.",
    "Error loading {name}" : "Erro ao carregar {name}",
    "Unsaved changes" : "Modificações não guardadas",
    "Your browser does not support videos." : "O seu navegador não suporta vídeos.",
    "Edit" : "Editar",
    "Open sidebar" : "Abrir barra lateral",
    "Download" : "Transferir",
    "Delete" : "Apagar",
    "View" : "Ver",
    "Name" : "Nome",
    "Save" : "Guardar",
    "Back" : "Anterior",
    "Loading …" : "A carregar...",
    "Reset" : "Reiniciar",
    "Cancel" : "Cancelar",
    "Continue" : "Continuar",
    "Undo" : "Desfazer",
    "Redo" : "Repetir",
    "Original" : "Original",
    "Custom" : "Personalizado",
    "Value" : "Valor",
    "Image" : "Imagem",
    "Text" : "Texto",
    "Size" : "Altura",
    "Name is required." : "Nome é obrigatório.",
    "Quality" : "Qualidade"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
